@@ -9,6 +9,7 @@ from .account import *
 
 def register():
     Pool.register(
+        Company,
         Address,
         CashflowTemplate,
         Cashflow,
@@ -36,6 +37,7 @@ def register():
         TrialBalance,
         BalanceSheet,
         IncomeStatement,
+        EquivalentInvoice,
         module='account_plus', type_='report')
     Pool.register(
         MoveForceDraw,
@@ -45,5 +47,5 @@ def register():
         PrintAuxiliaryParty,
         PrintTrialBalance,
         OpenCashflowStatement,
-        MoveFixNumber, 
+        MoveFixNumber,
         module='account_plus', type_='wizard')
